BbpsEvent class

Represents BBPS SDK events

Constructors

BbpsEvent({required String event, Map<String, dynamic>? payload, String? error, String? requestId, String? service, String? errorCode, String? errorMessage})
BbpsEvent.fromMap(Map map)
factory

Properties

error → String?
final
errorCode → String?
final
errorMessage → String?
final
event → String
final
hashCode → int
The hash code for this object.
no setterinherited
payload → Map<String, dynamic>?
final
requestId → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
service → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited