BbpsFlutterPlatform class abstract

Platform interface for BBPS Flutter Plugin

Inheritance
  • Object
  • PlatformInterface
  • BbpsFlutterPlatform
Implementers

Constructors

BbpsFlutterPlatform()

Properties

eventStream → Stream<BbpsEvent>
Stream of BBPS events
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createService({Map<String, dynamic>? params}) → Future<bool>
Create BBPS service
initiate({Map<String, dynamic>? params}) → Future<void>
Initiate BBPS session
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onBackPressed() → Future<bool>
Handle back press
process({Map<String, dynamic>? params}) → Future
Process BBPS action
terminate() → Future<bool>
Terminate BBPS service
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ BbpsFlutterPlatform
getter/setter pair