MethodChannelBbpsFlutter class

An implementation of BbpsFlutterPlatform that uses method channels.

Inheritance

Constructors

MethodChannelBbpsFlutter()

Properties

eventChannel EventChannel
The event channel for receiving BBPS events.
final
eventStream Stream<BbpsEvent>
Stream of BBPS events
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
methodChannel MethodChannel
The method channel used to interact with the native platform.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createService(String clientId) Future<bool>
Create BBPS service with clientId
override
initiate({required String agentId, required String mobile, required String deviceId, required String clientId, required String action, String? authToken}) Future<void>
Initiate BBPS session
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onBackPressed() Future<bool>
Handle back press
override
process(String action, {Map<String, dynamic>? params}) Future
Process BBPS action
override
terminate() Future<bool>
Terminate BBPS service
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited